import { Primitive } from "../primitives/primitive";
export class Composite {
    constructor() {
        /** @internal */
        this.scope = null;
    }
    /** @internal */
    props(coords) {
        return {};
    }
    /** Releases all GPU resources and renders this instance unusable. Also disposes any children. */
    dispose() {
        function recurse(renderable) {
            if (Array.isArray(renderable)) {
                for (const element of renderable) {
                    recurse(element);
                }
            }
            else if (renderable instanceof Composite) {
                recurse(renderable.children());
            }
            else if (renderable instanceof Primitive) {
                renderable.dispose();
            }
        }
        recurse(this.children());
    }
}
//# sourceMappingURL=composite.js.map