import { Primitive } from "./primitive";
import { createDataset } from "../dataset";
const DEFAULT_OPTIONS = {
    color: [0, 0, 0, 0.5],
};
export class Triangles extends Primitive {
    /**
     * @param vertices Set of 2D points in the form `[x0, y0, x1, y1, ...]` that
     * describe the (unindexed) set of triangles to render.
     */
    constructor(cg, vertices, options = {}) {
        super();
        this.cg = cg;
        const opts = Object.assign(Object.assign({}, DEFAULT_OPTIONS), options);
        this.vertices = createDataset(cg, vertices);
        this.color = opts.color.slice();
    }
    /** @internal */
    commands(glsl) {
        return {
            triangles: this.cg.regl({
                vert: `
          precision highp float;
          attribute vec2 position;

          ${glsl}

          void main() {
            gl_Position = domainToClip(position);
          }`,
                frag: `
          precision highp float;
          uniform vec4 color;
          void main() {
            gl_FragColor = color;
          }`,
                attributes: {
                    position: this.cg.regl.prop("position"),
                },
                uniforms: {
                    color: this.cg.regl.prop("color"),
                },
                count: this.cg.regl.prop("count"),
            }),
        };
    }
    /** @internal */
    render(commands) {
        const { vertices, color } = this;
        commands.triangles({
            position: vertices.buffer,
            count: vertices.count(2),
            color,
        });
    }
    /** Releases all GPU resources and renders this instance unusable. */
    dispose() {
        this.vertices.dispose();
    }
}
//# sourceMappingURL=triangles.js.map