import { Scale, Kind } from "./scale";
export class LinearScale extends Scale {
    constructor(domain, range) {
        super();
        /** @internal */
        this.kind = Kind.Linear;
        /** @internal */
        this.glsl = `
    float toDomain(float v, vec2 domain, vec2 range) {
      float qDomain = (domain.y - domain.x) / (range.y - range.x);
      return domain.x + qDomain * (v - range.x);
    }

    float toRange(float v, vec2 domain, vec2 range) {
      float qRange = (range.y - range.x) / (domain.y - domain.x);
      return range.x + qRange * (v - domain.x);
    }
  `;
        this._domain = [];
        this._range = [];
        this.qDomain = 1;
        this.qRange = 1;
        this.domain = domain;
        this.range = range;
    }
    get domain() {
        return this._domain.slice();
    }
    set domain(v) {
        this._domain = v.slice();
        this.updateQ();
    }
    get range() {
        return this._range.slice();
    }
    set range(v) {
        this._range = v.slice();
        this.updateQ();
    }
    toDomain(v) {
        return this._domain[0] + this.qDomain * (v - this._range[0]);
    }
    toRange(v) {
        return this._range[0] + this.qRange * (v - this._domain[0]);
    }
    updateQ() {
        this.qDomain = (this._domain[1] - this._domain[0]) / (this._range[1] - this._range[0]);
        this.qRange = 1 / this.qDomain;
    }
}
//# sourceMappingURL=linear.js.map